function slaRcc, tdb, ut1, wl, u, v 
;
;  - - - - - - -
;   s l a R c c
;  - - - - - - -
;
;  Relativistic clock correction:  the difference between proper time at
;  a point on the surface of the Earth and coordinate time in the Solar
;  System barycentric space-time frame of reference.
;
;  The proper time is Terrestrial Time TT;  the coordinate
;  time is an implementation of the Barycentric Dynamical Time TDB.
;
;  Given:
;    TDB   double   coordinate time (MJD: JD-2400000.5)
;    UT1   double   universal time (fraction of one day)
;    WL    double   clock longitude (radians west)
;    U     double   clock distance from Earth spin axis (km)
;    V     double   clock distance north of Earth equatorial plane (km)
;
;  Returned:
;    The clock correction, TDB-TT, in seconds.  TDB may be considered
;    to be the coordinate time in the Solar System barycentre frame of
;    reference, and TT is the proper time given by clocks at mean sea
;    level on the Earth.
;
;    The result has a main (annual) sinusoidal term of amplitude
;    approximately 0.00166 seconds, plus planetary terms up to about
;    20 microseconds, and lunar and diurnal terms up to 2 microseconds.
;
;    The variation arises from the transverse Doppler effect and the
;    gravitational red-shift as the observer varies in speed and moves
;    through different gravitational potentials.
;
;  The argument TDB is, strictly, the barycentric coordinate time;
;  however, the terrestrial proper time (TT) can in practice be used.
;
;  The geocentric model is that of Fairhead & Bretagnon (1990), in its
;  full form.  It was supplied by Fairhead (private communication) as a
;  FORTRAN subroutine.  The original Fairhead routine used explicit
;  formulae, in such large numbers that problems were experienced with
;  certain compilers (Microsoft Fortran on PC aborted with stack
;  overflow, Convex compiled successfully but extremely slowly).  The
;  present implementation is a complete recoding in C, with the original
;  Fairhead coefficients held in a table.  To optimize arithmetic
;  precision, the terms are accumulated in reverse order, smallest
;  first.  The numerical results from this C version agree with
;  those from the original Fairhead Fortran code to better than
;  10^-15 seconds, depending on the machine hardware.
;
;  The topocentric part of the model is from Moyer (1981) and
;  Murray (1983).
;
;  During the interval 1950-2050, the absolute accuracy is better
;  than +/- 3 nanoseconds relative to direct numerical integrations
;  using the JPL DE200/LE200 solar system ephemeris.
;
;  The IAU definition of TDB is that it must differ from TT only by
;  periodic terms.  Though practical, this is an imprecise definition
;  which ignores the existence of very long-period and secular effects
;  in the dynamics of the solar system.  As a consequence, different
;  implementations of TDB will, in general, differ in zero-point and
;  will drift linearly relative to one other.
;
;  References:
;    Bretagnon P, 1982 Astron. Astrophys., 114, 278-288.
;    Fairhead L & Bretagnon P, 1990, Astron. Astrophys., 229, 240-247.
;
;    Meeus J, 1984, l'Astronomie, 348-354.
;    Moyer T D, 1981, Cel. Mech., 23, 33.
;    Murray C A, 1983, Vectorial Astrometry, Adam Hilger.
;
;  Defined in slamac.h:  D2PI
;
;  Last revision:   13 May 1995
;
;  Copyright P.T.Wallace.  All rights reserved.
;  Fairhead and Bretagnon canonical coefficients
;
;  787 sets of three coefficients.
;
;  Each set is amplitude (microseconds)
;              frequency (radians per Julian millenium since J2000),
;              phase (radians).
;
;  Sets   1-474 are the T**0 terms,
;   "   475-679  "   "  T**1   "
;   "   680-764  "   "  T**2   "
;   "   765-784  "   "  T**3   "
;   "   785-787  "   "  T**4   "  .
fairhd=dblarr(2361)
fairhd = [1656.674564e-6,    6283.075849991d, 6.240054195d,$
        22.417471e-6,    5753.384884897d, 4.296977442d,$
        13.839792e-6,   12566.151699983d, 6.196904410d,$
         4.770086e-6,     529.690965095d, 0.444401603d,$
         4.676740e-6,    6069.776754553d, 4.021195093d,$
         2.256707e-6,     213.299095438d, 5.543113262d,$
         1.694205e-6,      -3.523118349d, 5.025132748d,$
         1.554905e-6,   77713.771467920d, 5.198467090d,$
         1.276839e-6,    7860.419392439d, 5.988822341d,$
         1.193379e-6,    5223.693919802d, 3.649823730d,$
         1.115322e-6,    3930.209696220d, 1.422745069d,$
         0.794185e-6,   11506.769769794d, 2.322313077d,$
         0.447061e-6,      26.298319800d, 3.615796498d,$
         0.435206e-6,    -398.149003408d, 4.349338347d,$
         0.600309e-6,    1577.343542448d, 2.678271909d,$
         0.496817e-6,    6208.294251424d, 5.696701824d,$
         0.486306e-6,    5884.926846583d, 0.520007179d,$
         0.432392e-6,      74.781598567d, 2.435898309d,$
         0.468597e-6,    6244.942814354d, 5.866398759d,$
         0.375510e-6,    5507.553238667d, 4.103476804d,$
         0.243085e-6,    -775.522611324d, 3.651837925d,$
         0.173435e-6,   18849.227549974d, 6.153743485d,$
         0.230685e-6,    5856.477659115d, 4.773852582d,$
         0.203747e-6,   12036.460734888d, 4.333987818d,$
         0.143935e-6,    -796.298006816d, 5.957517795d,$
         0.159080e-6,   10977.078804699d, 1.890075226d,$
         0.119979e-6,      38.133035638d, 4.551585768d,$
         0.118971e-6,    5486.777843175d, 1.914547226d,$
         0.116120e-6,    1059.381930189d, 0.873504123d,$
         0.137927e-6,   11790.629088659d, 1.135934669d,$
         0.098358e-6,    2544.314419883d, 0.092793886d,$
         0.101868e-6,   -5573.142801634d, 5.984503847d,$
         0.080164e-6,     206.185548437d, 2.095377709d,$
         0.079645e-6,    4694.002954708d, 2.949233637d,$
         0.062617e-6,      20.775395492d, 2.654394814d,$
         0.075019e-6,    2942.463423292d, 4.980931759d,$
         0.064397e-6,    5746.271337896d, 1.280308748d,$
         0.063814e-6,    5760.498431898d, 4.167901731d,$
         0.048042e-6,    2146.165416475d, 1.495846011d,$
         0.048373e-6,     155.420399434d, 2.251573730d,$
         0.058844e-6,     426.598190876d, 4.839650148d,$
         0.046551e-6,      -0.980321068d, 0.921573539d,$
         0.054139e-6,   17260.154654690d, 3.411091093d,$
         0.042411e-6,    6275.962302991d, 2.869567043d,$
         0.040184e-6,      -7.113547001d, 3.565975565d,$
         0.036564e-6,    5088.628839767d, 3.324679049d,$
         0.040759e-6,   12352.852604545d, 3.981496998d,$
         0.036507e-6,     801.820931124d, 6.248866009d,$
         0.036955e-6,    3154.687084896d, 5.071801441d,$
         0.042732e-6,     632.783739313d, 5.720622217d,$
         0.042560e-6,  161000.685737473d, 1.270837679d,$
         0.040480e-6,   15720.838784878d, 2.546610123d,$
         0.028244e-6,   -6286.598968340d, 5.069663519d,$
         0.033477e-6,    6062.663207553d, 4.144987272d,$
         0.034867e-6,     522.577418094d, 5.210064075d,$
         0.032438e-6,    6076.890301554d, 0.749317412d,$
         0.030215e-6,    7084.896781115d, 3.389610345d,$
         0.029247e-6,  -71430.695617928d, 4.183178762d,$
         0.033529e-6,    9437.762934887d, 2.404714239d,$
         0.032423e-6,    8827.390269875d, 5.541473556d,$
         0.027567e-6,    6279.552731642d, 5.040846034d,$
         0.029862e-6,   12139.553509107d, 1.770181024d,$
         0.022509e-6,   10447.387839604d, 1.460726241d,$
         0.020937e-6,    8429.241266467d, 0.652303414d,$
         0.020322e-6,     419.484643875d, 3.735430632d,$
         0.024816e-6,   -1194.447010225d, 1.087136918d,$
         0.025196e-6,    1748.016413067d, 2.901883301d,$
         0.021691e-6,   14143.495242431d, 5.952658009d,$
         0.017673e-6,    6812.766815086d, 3.186129845d,$
         0.022567e-6,    6133.512652857d, 3.307984806d,$
         0.016155e-6,   10213.285546211d, 1.331103168d,$
         0.014751e-6,    1349.867409659d, 4.308933301d,$
         0.015949e-6,    -220.412642439d, 4.005298270d,$
         0.015974e-6,   -2352.866153772d, 6.145309371d,$
         0.014223e-6,   17789.845619785d, 2.104551349d,$
         0.017806e-6,      73.297125859d, 3.475975097d,$
         0.013671e-6,    -536.804512095d, 5.971672571d,$
         0.011942e-6,    8031.092263058d, 2.053414715d,$
         0.014318e-6,   16730.463689596d, 3.016058075d,$
         0.012462e-6,     103.092774219d, 1.737438797d,$
         0.010962e-6,       3.590428652d, 2.196567739d,$
         0.015078e-6,   19651.048481098d, 3.969480770d,$
         0.010396e-6,     951.718406251d, 5.717799605d,$
         0.011707e-6,   -4705.732307544d, 2.654125618d,$
         0.010453e-6,    5863.591206116d, 1.913704550d,$
         0.012420e-6,    4690.479836359d, 4.734090399d,$
         0.011847e-6,    5643.178563677d, 5.489005403d,$
         0.008610e-6,    3340.612426700d, 3.661698944d,$
         0.011622e-6,    5120.601145584d, 4.863931876d,$
         0.010825e-6,     553.569402842d, 0.842715011d,$
         0.008666e-6,    -135.065080035d, 3.293406547d,$
         0.009963e-6,     149.563197135d, 4.870690598d,$
         0.009858e-6,    6309.374169791d, 1.061816410d,$
         0.007959e-6,     316.391869657d, 2.465042647d,$
         0.010099e-6,     283.859318865d, 1.942176992d,$
         0.007147e-6,    -242.728603974d, 3.661486981d,$
         0.007505e-6,    5230.807466803d, 4.920937029d,$
         0.008323e-6,   11769.853693166d, 1.229392026d,$
         0.007490e-6,   -6256.777530192d, 3.658444681d,$
         0.009370e-6,  149854.400134205d, 0.673880395d,$
         0.007117e-6,      38.027672636d, 5.294249518d,$
         0.007857e-6,   12168.002696575d, 0.525733528d,$
         0.007019e-6,    6206.809778716d, 0.837688810d,$
         0.006056e-6,     955.599741609d, 4.194535082d,$
         0.008107e-6,   13367.972631107d, 3.793235253d,$
         0.006731e-6,    5650.292110678d, 5.639906583d,$
         0.007332e-6,      36.648562930d, 0.114858677d,$
         0.006366e-6,    4164.311989613d, 2.262081818d,$
         0.006858e-6,    5216.580372801d, 0.642063318d,$
         0.006919e-6,    6681.224853400d, 6.018501522d,$
         0.006826e-6,    7632.943259650d, 3.458654112d,$
         0.005308e-6,   -1592.596013633d, 2.500382359d,$
         0.005096e-6,   11371.704689758d, 2.547107806d,$
         0.004841e-6,    5333.900241022d, 0.437078094d,$
         0.005582e-6,    5966.683980335d, 2.246174308d,$
         0.006304e-6,   11926.254413669d, 2.512929171d,$
         0.006603e-6,   23581.258177318d, 5.393136889d,$
         0.005123e-6,      -1.484472708d, 2.999641028d,$
         0.004648e-6,    1589.072895284d, 1.275847090d,$
         0.005119e-6,    6438.496249426d, 1.486539246d,$
         0.004521e-6,    4292.330832950d, 6.140635794d,$
         0.005680e-6,   23013.539539587d, 4.557814849d,$
         0.005488e-6,      -3.455808046d, 0.090675389d,$
         0.004193e-6,    7234.794256242d, 4.869091389d,$
         0.003742e-6,    7238.675591600d, 4.691976180d,$
         0.004148e-6,    -110.206321219d, 3.016173439d,$
         0.004553e-6,   11499.656222793d, 5.554998314d,$
         0.004892e-6,    5436.993015240d, 1.475415597d,$
         0.004044e-6,    4732.030627343d, 1.398784824d,$
         0.004164e-6,   12491.370101415d, 5.650931916d,$
         0.004349e-6,   11513.883316794d, 2.181745369d,$
         0.003919e-6,   12528.018664345d, 5.823319737d,$
         0.003129e-6,    6836.645252834d, 0.003844094d,$
         0.004080e-6,   -7058.598461315d, 3.690360123d,$
         0.003270e-6,      76.266071276d, 1.517189902d,$
         0.002954e-6,    6283.143160294d, 4.447203799d,$
         0.002872e-6,      28.449187468d, 1.158692983d,$
         0.002881e-6,     735.876513532d, 0.349250250d,$
         0.003279e-6,    5849.364112115d, 4.893384368d,$
         0.003625e-6,    6209.778724132d, 1.473760578d,$
         0.003074e-6,     949.175608970d, 5.185878737d,$
         0.002775e-6,    9917.696874510d, 1.030026325d,$
         0.002646e-6,   10973.555686350d, 3.918259169d,$
         0.002575e-6,   25132.303399966d, 6.109659023d,$
         0.003500e-6,     263.083923373d, 1.892100742d,$
         0.002740e-6,   18319.536584880d, 4.320519510d,$
         0.002464e-6,     202.253395174d, 4.698203059d,$
         0.002409e-6,       2.542797281d, 5.325009315d,$
         0.003354e-6,  -90955.551694697d, 1.942656623d,$
         0.002296e-6,    6496.374945429d, 5.061810696d,$
         0.003002e-6,    6172.869528772d, 2.797822767d,$
         0.003202e-6,   27511.467873537d, 0.531673101d,$
         0.002954e-6,   -6283.008539689d, 4.533471191d,$
         0.002353e-6,     639.897286314d, 3.734548088d,$
         0.002401e-6,   16200.772724501d, 2.605547070d,$
         0.003053e-6,  233141.314403759d, 3.029030662d,$
         0.003024e-6,   83286.914269554d, 2.355556099d,$
         0.002863e-6,   17298.182327326d, 5.240963796d,$
         0.002103e-6,   -7079.373856808d, 5.756641637d,$
         0.002303e-6,   83996.847317911d, 2.013686814d,$
         0.002303e-6,   18073.704938650d, 1.089100410d,$
         0.002381e-6,      63.735898303d, 0.759188178d,$
         0.002493e-6,    6386.168624210d, 0.645026535d,$
         0.002366e-6,       3.932153263d, 6.215885448d,$
         0.002169e-6,   11015.106477335d, 4.845297676d,$
         0.002397e-6,    6243.458341645d, 3.809290043d,$
         0.002183e-6,    1162.474704408d, 6.179611691d,$
         0.002353e-6,    6246.427287062d, 4.781719760d,$
         0.002199e-6,    -245.831646229d, 5.956152284d,$
         0.001729e-6,    3894.181829542d, 1.264976635d,$
         0.001896e-6,   -3128.388765096d, 4.914231596d,$
         0.002085e-6,      35.164090221d, 1.405158503d,$
         0.002024e-6,   14712.317116458d, 2.752035928d,$
         0.001737e-6,    6290.189396992d, 5.280820144d,$
         0.002229e-6,     491.557929457d, 1.571007057d,$
         0.001602e-6,   14314.168113050d, 4.203664806d,$
         0.002186e-6,     454.909366527d, 1.402101526d,$
         0.001897e-6,   22483.848574493d, 4.167932508d,$
         0.001825e-6,   -3738.761430108d, 0.545828785d,$
         0.001894e-6,    1052.268383188d, 5.817167450d,$
         0.001421e-6,      20.355319399d, 2.419886601d,$
         0.001408e-6,   10984.192351700d, 2.732084787d,$
         0.001847e-6,   10873.986030480d, 2.903477885d,$
         0.001391e-6,   -8635.942003763d, 0.593891500d,$
         0.001388e-6,      -7.046236698d, 1.166145902d,$
         0.001810e-6,  -88860.057071188d, 0.487355242d,$
         0.001288e-6,   -1990.745017041d, 3.913022880d,$
         0.001297e-6,   23543.230504682d, 3.063805171d,$
         0.001335e-6,    -266.607041722d, 3.995764039d,$
         0.001376e-6,   10969.965257698d, 5.152914309d,$
         0.001745e-6,  244287.600007027d, 3.626395673d,$
         0.001649e-6,   31441.677569757d, 1.952049260d,$
         0.001416e-6,    9225.539273283d, 4.996408389d,$
         0.001238e-6,    4804.209275927d, 5.503379738d,$
         0.001472e-6,    4590.910180489d, 4.164913291d,$
         0.001169e-6,    6040.347246017d, 5.841719038d,$
         0.001039e-6,    5540.085789459d, 2.769753519d,$
         0.001004e-6,    -170.672870619d, 0.755008103d,$
         0.001284e-6,   10575.406682942d, 5.306538209d,$
         0.001278e-6,      71.812653151d, 4.713486491d,$
         0.001321e-6,   18209.330263660d, 2.624866359d,$
         0.001297e-6,   21228.392023546d, 0.382603541d,$
         0.000954e-6,    6282.095528923d, 0.882213514d,$
         0.001145e-6,    6058.731054289d, 1.169483931d,$
         0.000979e-6,    5547.199336460d, 5.448375984d,$
         0.000987e-6,   -6262.300454499d, 2.656486959d,$
         0.001070e-6, -154717.609887482d, 1.827624012d,$
         0.000991e-6,    4701.116501708d, 4.387001801d,$
         0.001155e-6,     -14.227094002d, 3.042700750d,$
         0.001176e-6,     277.034993741d, 3.335519004d,$
         0.000890e-6,   13916.019109642d, 5.601498297d,$
         0.000884e-6,   -1551.045222648d, 1.088831705d,$
         0.000876e-6,    5017.508371365d, 3.969902609d,$
         0.000806e-6,   15110.466119866d, 5.142876744d,$
         0.000773e-6,   -4136.910433516d, 0.022067765d,$
         0.001077e-6,     175.166059800d, 1.844913056d,$
         0.000954e-6,   -6284.056171060d, 0.968480906d,$
         0.000737e-6,    5326.786694021d, 4.923831588d,$
         0.000845e-6,    -433.711737877d, 4.749245231d,$
         0.000819e-6,    8662.240323563d, 5.991247817d,$
         0.000852e-6,     199.072001436d, 2.189604979d,$
         0.000723e-6,   17256.631536341d, 6.068719637d,$
         0.000940e-6,    6037.244203762d, 6.197428148d,$
         0.000885e-6,   11712.955318231d, 3.280414875d,$
         0.000706e-6,   12559.038152982d, 2.824848947d,$
         0.000732e-6,    2379.164473572d, 2.501813417d,$
         0.000764e-6,   -6127.655450557d, 2.236346329d,$
         0.000908e-6,     131.541961686d, 2.521257490d,$
         0.000907e-6,   35371.887265976d, 3.370195967d,$
         0.000673e-6,    1066.495477190d, 3.876512374d,$
         0.000814e-6,   17654.780539750d, 4.627122566d,$
         0.000630e-6,      36.027866677d, 0.156368499d,$
         0.000798e-6,     515.463871093d, 5.151962502d,$
         0.000798e-6,     148.078724426d, 5.909225055d,$
         0.000806e-6,     309.278322656d, 6.054064447d,$
         0.000607e-6,     -39.617508346d, 2.839021623d,$
         0.000601e-6,     412.371096874d, 3.984225404d,$
         0.000646e-6,   11403.676995575d, 3.852959484d,$
         0.000704e-6,   13521.751441591d, 2.300991267d,$
         0.000603e-6,  -65147.619767937d, 4.140083146d,$
         0.000609e-6,   10177.257679534d, 0.437122327d,$
         0.000631e-6,    5767.611978898d, 4.026532329d,$
         0.000576e-6,   11087.285125918d, 4.760293101d,$
         0.000674e-6,   14945.316173554d, 6.270510511d,$
         0.000726e-6,    5429.879468239d, 6.039606892d,$
         0.000710e-6,   28766.924424484d, 5.672617711d,$
         0.000647e-6,   11856.218651625d, 3.397132627d,$
         0.000678e-6,   -5481.254918868d, 6.249666675d,$
         0.000618e-6,   22003.914634870d, 2.466427018d,$
         0.000738e-6,    6134.997125565d, 2.242668890d,$
         0.000660e-6,     625.670192312d, 5.864091907d,$
         0.000694e-6,    3496.032826134d, 2.668309141d,$
         0.000531e-6,    6489.261398429d, 1.681888780d,$
         0.000611e-6, -143571.324284214d, 2.424978312d,$
         0.000575e-6,   12043.574281889d, 4.216492400d,$
         0.000553e-6,   12416.588502848d, 4.772158039d,$
         0.000689e-6,    4686.889407707d, 6.224271088d,$
         0.000495e-6,    7342.457780181d, 3.817285811d,$
         0.000567e-6,    3634.621024518d, 1.649264690d,$
         0.000515e-6,   18635.928454536d, 3.945345892d,$
         0.000486e-6,    -323.505416657d, 4.061673868d,$
         0.000662e-6,   25158.601719765d, 1.794058369d,$
         0.000509e-6,     846.082834751d, 3.053874588d,$
         0.000472e-6,  -12569.674818332d, 5.112133338d,$
         0.000461e-6,    6179.983075773d, 0.513669325d,$
         0.000641e-6,   83467.156352816d, 3.210727723d,$
         0.000520e-6,   10344.295065386d, 2.445597761d,$
         0.000493e-6,   18422.629359098d, 1.676939306d,$
         0.000478e-6,    1265.567478626d, 5.487314569d,$
         0.000472e-6,     -18.159247265d, 1.999707589d,$
         0.000559e-6,   11190.377900137d, 5.783236356d,$
         0.000494e-6,    9623.688276691d, 3.022645053d,$
         0.000463e-6,    5739.157790895d, 1.411223013d,$
         0.000432e-6,   16858.482532933d, 1.179256434d,$
         0.000574e-6,   72140.628666286d, 1.758191830d,$
         0.000484e-6,   17267.268201691d, 3.290589143d,$
         0.000550e-6,    4907.302050146d, 0.864024298d,$
         0.000399e-6,      14.977853527d, 2.094441910d,$
         0.000491e-6,     224.344795702d, 0.878372791d,$
         0.000432e-6,   20426.571092422d, 6.003829241d,$
         0.000481e-6,    5749.452731634d, 4.309591964d,$
         0.000480e-6,    5757.317038160d, 1.142348571d,$
         0.000485e-6,    6702.560493867d, 0.210580917d,$
         0.000426e-6,    6055.549660552d, 4.274476529d,$
         0.000480e-6,    5959.570433334d, 5.031351030d,$
         0.000466e-6,   12562.628581634d, 4.959581597d,$
         0.000520e-6,   39302.096962196d, 4.788002889d,$
         0.000458e-6,   12132.439962106d, 1.880103788d,$
         0.000470e-6,   12029.347187887d, 1.405611197d,$
         0.000416e-6,   -7477.522860216d, 1.082356330d,$
         0.000449e-6,   11609.862544012d, 4.179989585d,$
         0.000465e-6,   17253.041107690d, 0.353496295d,$
         0.000362e-6,   -4535.059436924d, 1.583849576d,$
         0.000383e-6,   21954.157609398d, 3.747376371d,$
         0.000389e-6,      17.252277143d, 1.395753179d,$
         0.000331e-6,   18052.929543158d, 0.566790582d,$
         0.000430e-6,   13517.870106233d, 0.685827538d,$
         0.000368e-6,   -5756.908003246d, 0.731374317d,$
         0.000330e-6,   10557.594160824d, 3.710043680d,$
         0.000332e-6,   20199.094959633d, 1.652901407d,$
         0.000384e-6,   11933.367960670d, 5.827781531d,$
         0.000387e-6,   10454.501386605d, 2.541182564d,$
         0.000325e-6,   15671.081759407d, 2.178850542d,$
         0.000318e-6,     138.517496871d, 2.253253037d,$
         0.000305e-6,    9388.005909415d, 0.578340206d,$
         0.000352e-6,    5749.861766548d, 3.000297967d,$
         0.000311e-6,    6915.859589305d, 1.693574249d,$
         0.000297e-6,   24072.921469776d, 1.997249392d,$
         0.000363e-6,    -640.877607382d, 5.071820966d,$
         0.000323e-6,   12592.450019783d, 1.072262823d,$
         0.000341e-6,   12146.667056108d, 4.700657997d,$
         0.000290e-6,    9779.108676125d, 1.812320441d,$
         0.000342e-6,    6132.028180148d, 4.322238614d,$
         0.000329e-6,    6268.848755990d, 3.033827743d,$
         0.000374e-6,   17996.031168222d, 3.388716544d,$
         0.000285e-6,    -533.214083444d, 4.687313233d,$
         0.000338e-6,    6065.844601290d, 0.877776108d,$
         0.000276e-6,      24.298513841d, 0.770299429d,$
         0.000336e-6,   -2388.894020449d, 5.353796034d,$
         0.000290e-6,    3097.883822726d, 4.075291557d,$
         0.000318e-6,     709.933048357d, 5.941207518d,$
         0.000271e-6,   13095.842665077d, 3.208912203d,$
         0.000331e-6,    6073.708907816d, 4.007881169d,$
         0.000292e-6,     742.990060533d, 2.714333592d,$
         0.000362e-6,   29088.811415985d, 3.215977013d,$
         0.000280e-6,   12359.966151546d, 0.710872502d,$
         0.000267e-6,   10440.274292604d, 4.730108488d,$
         0.000262e-6,     838.969287750d, 1.327720272d,$
         0.000250e-6,   16496.361396202d, 0.898769761d,$
         0.000325e-6,   20597.243963041d, 0.180044365d,$
         0.000268e-6,    6148.010769956d, 5.152666276d,$
         0.000284e-6,    5636.065016677d, 5.655385808d,$
         0.000301e-6,    6080.822454817d, 2.135396205d,$
         0.000294e-6,    -377.373607916d, 3.708784168d,$
         0.000236e-6,    2118.763860378d, 1.733578756d,$
         0.000234e-6,    5867.523359379d, 5.575209112d,$
         0.000268e-6, -226858.238553767d, 0.069432392d,$
         0.000265e-6,  167283.761587465d, 4.369302826d,$
         0.000280e-6,   28237.233459389d, 5.304829118d,$
         0.000292e-6,   12345.739057544d, 4.096094132d,$
         0.000223e-6,   19800.945956225d, 3.069327406d,$
         0.000301e-6,   43232.306658416d, 6.205311188d,$
         0.000264e-6,   18875.525869774d, 1.417263408d,$
         0.000304e-6,   -1823.175188677d, 3.409035232d,$
         0.000301e-6,     109.945688789d, 0.510922054d,$
         0.000260e-6,     813.550283960d, 2.389438934d,$
         0.000299e-6,  316428.228673312d, 5.384595078d,$
         0.000211e-6,    5756.566278634d, 3.789392838d,$
         0.000209e-6,    5750.203491159d, 1.661943545d,$
         0.000240e-6,   12489.885628707d, 5.684549045d,$
         0.000216e-6,    6303.851245484d, 3.862942261d,$
         0.000203e-6,    1581.959348283d, 5.549853589d,$
         0.000200e-6,    5642.198242609d, 1.016115785d,$
         0.000197e-6,     -70.849445304d, 4.690702525d,$
         0.000227e-6,    6287.008003254d, 2.911891613d,$
         0.000197e-6,     533.623118358d, 1.048982898d,$
         0.000205e-6,   -6279.485421340d, 1.829362730d,$
         0.000209e-6,  -10988.808157535d, 2.636140084d,$
         0.000208e-6,    -227.526189440d, 4.127883842d,$
         0.000191e-6,     415.552490612d, 4.401165650d,$
         0.000190e-6,   29296.615389579d, 4.175658539d,$
         0.000264e-6,   66567.485864652d, 4.601102551d,$
         0.000256e-6,   -3646.350377354d, 0.506364778d,$
         0.000188e-6,   13119.721102825d, 2.032195842d,$
         0.000185e-6,    -209.366942175d, 4.694756586d,$
         0.000198e-6,   25934.124331089d, 3.832703118d,$
         0.000195e-6,    4061.219215394d, 3.308463427d,$
         0.000234e-6,    5113.487598583d, 1.716090661d,$
         0.000188e-6,    1478.866574064d, 5.686865780d,$
         0.000222e-6,   11823.161639450d, 1.942386641d,$
         0.000181e-6,   10770.893256262d, 1.999482059d,$
         0.000171e-6,    6546.159773364d, 1.182807992d,$
         0.000206e-6,      70.328180442d, 5.934076062d,$
         0.000169e-6,   20995.392966449d, 2.169080622d,$
         0.000191e-6,   10660.686935042d, 5.405515999d,$
         0.000228e-6,   33019.021112205d, 4.656985514d,$
         0.000184e-6,   -4933.208440333d, 3.327476868d,$
         0.000220e-6,    -135.625325010d, 1.765430262d,$
         0.000166e-6,   23141.558382925d, 3.454132746d,$
         0.000191e-6,    6144.558353121d, 5.020393445d,$
         0.000180e-6,    6084.003848555d, 0.602182191d,$
         0.000163e-6,   17782.732072784d, 4.960593133d,$
         0.000225e-6,   16460.333529525d, 2.596451817d,$
         0.000222e-6,    5905.702242076d, 3.731990323d,$
         0.000204e-6,     227.476132789d, 5.636192701d,$
         0.000159e-6,   16737.577236597d, 3.600691544d,$
         0.000200e-6,    6805.653268085d, 0.868220961d,$
         0.000187e-6,   11919.140866668d, 2.629456641d,$
         0.000161e-6,     127.471796607d, 2.862574720d,$
         0.000205e-6,    6286.666278643d, 1.742882331d,$
         0.000189e-6,     153.778810485d, 4.812372643d,$
         0.000168e-6,   16723.350142595d, 0.027860588d,$
         0.000149e-6,   11720.068865232d, 0.659721876d,$
         0.000189e-6,    5237.921013804d, 5.245313000d,$
         0.000143e-6,    6709.674040867d, 4.317625647d,$
         0.000146e-6,    4487.817406270d, 4.815297007d,$
         0.000144e-6,    -664.756045130d, 5.381366880d,$
         0.000175e-6,    5127.714692584d, 4.728443327d,$
         0.000162e-6,    6254.626662524d, 1.435132069d,$
         0.000187e-6,   47162.516354635d, 1.354371923d,$
         0.000146e-6,   11080.171578918d, 3.369695406d,$
         0.000180e-6,    -348.924420448d, 2.490902145d,$
         0.000148e-6,     151.047669843d, 3.799109588d,$
         0.000157e-6,    6197.248551160d, 1.284375887d,$
         0.000167e-6,     146.594251718d, 0.759969109d,$
         0.000133e-6,   -5331.357443741d, 5.409701889d,$
         0.000154e-6,      95.979227218d, 3.366890614d,$
         0.000148e-6,   -6418.140930027d, 3.384104996d,$
         0.000128e-6,   -6525.804453965d, 3.803419985d,$
         0.000130e-6,   11293.470674356d, 0.939039445d,$
         0.000152e-6,   -5729.506447149d, 0.734117523d,$
         0.000138e-6,     210.117701700d, 2.564216078d,$
         0.000123e-6,    6066.595360816d, 4.517099537d,$
         0.000140e-6,   18451.078546566d, 0.642049130d,$
         0.000126e-6,   11300.584221356d, 3.485280663d,$
         0.000119e-6,   10027.903195729d, 3.217431161d,$
         0.000151e-6,    4274.518310832d, 4.404359108d,$
         0.000117e-6,    6072.958148291d, 0.366324650d,$
         0.000165e-6,   -7668.637425143d, 4.298212528d,$
         0.000117e-6,   -6245.048177356d, 5.379518958d,$
         0.000130e-6,   -5888.449964932d, 4.527681115d,$
         0.000121e-6,    -543.918059096d, 6.109429504d,$
         0.000162e-6,    9683.594581116d, 5.720092446d,$
         0.000141e-6,    6219.339951688d, 0.679068671d,$
         0.000118e-6,   22743.409379516d, 4.881123092d,$
         0.000129e-6,    1692.165669502d, 0.351407289d,$
         0.000126e-6,    5657.405657679d, 5.146592349d,$
         0.000114e-6,     728.762966531d, 0.520791814d,$
         0.000120e-6,      52.596639600d, 0.948516300d,$
         0.000115e-6,      65.220371012d, 3.504914846d,$
         0.000126e-6,    5881.403728234d, 5.577502482d,$
         0.000158e-6,  163096.180360983d, 2.957128968d,$
         0.000134e-6,   12341.806904281d, 2.598576764d,$
         0.000151e-6,   16627.370915377d, 3.985702050d,$
         0.000109e-6,    1368.660252845d, 0.014730471d,$
         0.000131e-6,    6211.263196841d, 0.085077024d,$
         0.000146e-6,    5792.741760812d, 0.708426604d,$
         0.000146e-6,     -77.750543984d, 3.121576600d,$
         0.000107e-6,    5341.013788022d, 0.288231904d,$
         0.000138e-6,    6281.591377283d, 2.797450317d,$
         0.000113e-6,   -6277.552925684d, 2.788904128d,$
         0.000115e-6,    -525.758811831d, 5.895222200d,$
         0.000138e-6,    6016.468808270d, 6.096188999d,$
         0.000139e-6,   23539.707386333d, 2.028195445d,$
         0.000146e-6,   -4176.041342449d, 4.660008502d,$
         0.000107e-6,   16062.184526117d, 4.066520001d,$
         0.000142e-6,   83783.548222473d, 2.936315115d,$
         0.000128e-6,    9380.959672717d, 3.223844306d,$
         0.000135e-6,    6205.325306007d, 1.638054048d,$
         0.000101e-6,    2699.734819318d, 5.481603249d,$
         0.000104e-6,    -568.821874027d, 2.205734493d,$
         0.000103e-6,    6321.103522627d, 2.440421099d,$
         0.000119e-6,    6321.208885629d, 2.547496264d,$
         0.000138e-6,    1975.492545856d, 2.314608466d,$
         0.000121e-6,     137.033024162d, 4.539108237d,$
         0.000123e-6,   19402.796952817d, 4.538074405d,$
         0.000119e-6,   22805.735565994d, 2.869040566d,$
         0.000133e-6,   64471.991241142d, 6.056405489d,$
         0.000129e-6,     -85.827298831d, 2.540635083d,$
         0.000131e-6,   13613.804277336d, 4.005732868d,$
         0.000104e-6,    9814.604100291d, 1.959967212d,$
         0.000112e-6,   16097.679950283d, 3.589026260d,$
         0.000123e-6,    2107.034507542d, 1.728627253d,$
         0.000121e-6,   36949.230808424d, 6.072332087d,$
         0.000108e-6,  -12539.853380183d, 3.716133846d,$
         0.000113e-6,   -7875.671863624d, 2.725771122d,$
         0.000109e-6,    4171.425536614d, 4.033338079d,$
         0.000101e-6,    6247.911759770d, 3.441347021d,$
         0.000113e-6,    7330.728427345d, 0.656372122d,$
         0.000113e-6,   51092.726050855d, 2.791483066d,$
         0.000106e-6,    5621.842923210d, 1.815323326d,$
         0.000101e-6,     111.430161497d, 5.711033677d,$
         0.000103e-6,     909.818733055d, 2.812745443d,$
         0.000101e-6,    1790.642637886d, 1.965746028d,$
       102.156724e-6,    6283.075849991d, 4.249032005d,$
         1.706807e-6,   12566.151699983d, 4.205904248d,$
         0.269668e-6,     213.299095438d, 3.400290479d,$
         0.265919e-6,     529.690965095d, 5.836047367d,$
         0.210568e-6,      -3.523118349d, 6.262738348d,$
         0.077996e-6,    5223.693919802d, 4.670344204d,$
         0.054764e-6,    1577.343542448d, 4.534800170d,$
         0.059146e-6,      26.298319800d, 1.083044735d,$
         0.034420e-6,    -398.149003408d, 5.980077351d,$
         0.032088e-6,   18849.227549974d, 4.162913471d,$
         0.033595e-6,    5507.553238667d, 5.980162321d,$
         0.029198e-6,    5856.477659115d, 0.623811863d,$
         0.027764e-6,     155.420399434d, 3.745318113d,$
         0.025190e-6,    5746.271337896d, 2.980330535d,$
         0.022997e-6,    -796.298006816d, 1.174411803d,$
         0.024976e-6,    5760.498431898d, 2.467913690d,$
         0.021774e-6,     206.185548437d, 3.854787540d,$
         0.017925e-6,    -775.522611324d, 1.092065955d,$
         0.013794e-6,     426.598190876d, 2.699831988d,$
         0.013276e-6,    6062.663207553d, 5.845801920d,$
         0.011774e-6,   12036.460734888d, 2.292832062d,$
         0.012869e-6,    6076.890301554d, 5.333425680d,$
         0.012152e-6,    1059.381930189d, 6.222874454d,$
         0.011081e-6,      -7.113547001d, 5.154724984d,$
         0.010143e-6,    4694.002954708d, 4.044013795d,$
         0.009357e-6,    5486.777843175d, 3.416081409d,$
         0.010084e-6,     522.577418094d, 0.749320262d,$
         0.008587e-6,   10977.078804699d, 2.777152598d,$
         0.008628e-6,    6275.962302991d, 4.562060226d,$
         0.008158e-6,    -220.412642439d, 5.806891533d,$
         0.007746e-6,    2544.314419883d, 1.603197066d,$
         0.007670e-6,    2146.165416475d, 3.000200440d,$
         0.007098e-6,      74.781598567d, 0.443725817d,$
         0.006180e-6,    -536.804512095d, 1.302642751d,$
         0.005818e-6,    5088.628839767d, 4.827723531d,$
         0.004945e-6,   -6286.598968340d, 0.268305170d,$
         0.004774e-6,    1349.867409659d, 5.808636673d,$
         0.004687e-6,    -242.728603974d, 5.154890570d,$
         0.006089e-6,    1748.016413067d, 4.403765209d,$
         0.005975e-6,   -1194.447010225d, 2.583472591d,$
         0.004229e-6,     951.718406251d, 0.931172179d,$
         0.005264e-6,     553.569402842d, 2.336107252d,$
         0.003049e-6,    5643.178563677d, 1.362634430d,$
         0.002974e-6,    6812.766815086d, 1.583012668d,$
         0.003403e-6,   -2352.866153772d, 2.552189886d,$
         0.003030e-6,     419.484643875d, 5.286473844d,$
         0.003210e-6,      -7.046236698d, 1.863796539d,$
         0.003058e-6,    9437.762934887d, 4.226420633d,$
         0.002589e-6,   12352.852604545d, 1.991935820d,$
         0.002927e-6,    5216.580372801d, 2.319951253d,$
         0.002425e-6,    5230.807466803d, 3.084752833d,$
         0.002656e-6,    3154.687084896d, 2.487447866d,$
         0.002445e-6,   10447.387839604d, 2.347139160d,$
         0.002990e-6,    4690.479836359d, 6.235872050d,$
         0.002890e-6,    5863.591206116d, 0.095197563d,$
         0.002498e-6,    6438.496249426d, 2.994779800d,$
         0.001889e-6,    8031.092263058d, 3.569003717d,$
         0.002567e-6,     801.820931124d, 3.425611498d,$
         0.001803e-6,  -71430.695617928d, 2.192295512d,$
         0.001782e-6,       3.932153263d, 5.180433689d,$
         0.001694e-6,   -4705.732307544d, 4.641779174d,$
         0.001704e-6,   -1592.596013633d, 3.997097652d,$
         0.001735e-6,    5849.364112115d, 0.417558428d,$
         0.001643e-6,    8429.241266467d, 2.180619584d,$
         0.001680e-6,      38.133035638d, 4.164529426d,$
         0.002045e-6,    7084.896781115d, 0.526323854d,$
         0.001458e-6,    4292.330832950d, 1.356098141d,$
         0.001437e-6,      20.355319399d, 3.895439360d,$
         0.001738e-6,    6279.552731642d, 0.087484036d,$
         0.001367e-6,   14143.495242431d, 3.987576591d,$
         0.001344e-6,    7234.794256242d, 0.090454338d,$
         0.001438e-6,   11499.656222793d, 0.974387904d,$
         0.001257e-6,    6836.645252834d, 1.509069366d,$
         0.001358e-6,   11513.883316794d, 0.495572260d,$
         0.001628e-6,    7632.943259650d, 4.968445721d,$
         0.001169e-6,     103.092774219d, 2.838496795d,$
         0.001162e-6,    4164.311989613d, 3.408387778d,$
         0.001092e-6,    6069.776754553d, 3.617942651d,$
         0.001008e-6,   17789.845619785d, 0.286350174d,$
         0.001008e-6,     639.897286314d, 1.610762073d,$
         0.000918e-6,   10213.285546211d, 5.532798067d,$
         0.001011e-6,   -6256.777530192d, 0.661826484d,$
         0.000753e-6,   16730.463689596d, 3.905030235d,$
         0.000737e-6,   11926.254413669d, 4.641956361d,$
         0.000694e-6,    3340.612426700d, 2.111120332d,$
         0.000701e-6,    3894.181829542d, 2.760823491d,$
         0.000689e-6,    -135.065080035d, 4.768800780d,$
         0.000700e-6,   13367.972631107d, 5.760439898d,$
         0.000664e-6,    6040.347246017d, 1.051215840d,$
         0.000654e-6,    5650.292110678d, 4.911332503d,$
         0.000788e-6,    6681.224853400d, 4.699648011d,$
         0.000628e-6,    5333.900241022d, 5.024608847d,$
         0.000755e-6,    -110.206321219d, 4.370971253d,$
         0.000628e-6,    6290.189396992d, 3.660478857d,$
         0.000635e-6,   25132.303399966d, 4.121051532d,$
         0.000534e-6,    5966.683980335d, 1.173284524d,$
         0.000543e-6,    -433.711737877d, 0.345585464d,$
         0.000517e-6,   -1990.745017041d, 5.414571768d,$
         0.000504e-6,    5767.611978898d, 2.328281115d,$
         0.000485e-6,    5753.384884897d, 1.685874771d,$
         0.000463e-6,    7860.419392439d, 5.297703006d,$
         0.000604e-6,     515.463871093d, 0.591998446d,$
         0.000443e-6,   12168.002696575d, 4.830881244d,$
         0.000570e-6,     199.072001436d, 3.899190272d,$
         0.000465e-6,   10969.965257698d, 0.476681802d,$
         0.000424e-6,   -7079.373856808d, 1.112242763d,$
         0.000427e-6,     735.876513532d, 1.994214480d,$
         0.000478e-6,   -6127.655450557d, 3.778025483d,$
         0.000414e-6,   10973.555686350d, 5.441088327d,$
         0.000512e-6,    1589.072895284d, 0.107123853d,$
         0.000378e-6,   10984.192351700d, 0.915087231d,$
         0.000402e-6,   11371.704689758d, 4.107281715d,$
         0.000453e-6,    9917.696874510d, 1.917490952d,$
         0.000395e-6,     149.563197135d, 2.763124165d,$
         0.000371e-6,    5739.157790895d, 3.112111866d,$
         0.000350e-6,   11790.629088659d, 0.440639857d,$
         0.000356e-6,    6133.512652857d, 5.444568842d,$
         0.000344e-6,     412.371096874d, 5.676832684d,$
         0.000383e-6,     955.599741609d, 5.559734846d,$
         0.000333e-6,    6496.374945429d, 0.261537984d,$
         0.000340e-6,    6055.549660552d, 5.975534987d,$
         0.000334e-6,    1066.495477190d, 2.335063907d,$
         0.000399e-6,   11506.769769794d, 5.321230910d,$
         0.000314e-6,   18319.536584880d, 2.313312404d,$
         0.000424e-6,    1052.268383188d, 1.211961766d,$
         0.000307e-6,      63.735898303d, 3.169551388d,$
         0.000329e-6,      29.821438149d, 6.106912080d,$
         0.000357e-6,    6309.374169791d, 4.223760346d,$
         0.000312e-6,   -3738.761430108d, 2.180556645d,$
         0.000301e-6,     309.278322656d, 1.499984572d,$
         0.000268e-6,   12043.574281889d, 2.447520648d,$
         0.000257e-6,   12491.370101415d, 3.662331761d,$
         0.000290e-6,     625.670192312d, 1.272834584d,$
         0.000256e-6,    5429.879468239d, 1.913426912d,$
         0.000339e-6,    3496.032826134d, 4.165930011d,$
         0.000283e-6,    3930.209696220d, 4.325565754d,$
         0.000241e-6,   12528.018664345d, 3.832324536d,$
         0.000304e-6,    4686.889407707d, 1.612348468d,$
         0.000259e-6,   16200.772724501d, 3.470173146d,$
         0.000238e-6,   12139.553509107d, 1.147977842d,$
         0.000236e-6,    6172.869528772d, 3.776271728d,$
         0.000296e-6,   -7058.598461315d, 0.460368852d,$
         0.000306e-6,   10575.406682942d, 0.554749016d,$
         0.000251e-6,   17298.182327326d, 0.834332510d,$
         0.000290e-6,    4732.030627343d, 4.759564091d,$
         0.000261e-6,    5884.926846583d, 0.298259862d,$
         0.000249e-6,    5547.199336460d, 3.749366406d,$
         0.000213e-6,   11712.955318231d, 5.415666119d,$
         0.000223e-6,    4701.116501708d, 2.703203558d,$
         0.000268e-6,    -640.877607382d, 0.283670793d,$
         0.000209e-6,    5636.065016677d, 1.238477199d,$
         0.000193e-6,   10177.257679534d, 1.943251340d,$
         0.000182e-6,    6283.143160294d, 2.456157599d,$
         0.000184e-6,    -227.526189440d, 5.888038582d,$
         0.000182e-6,   -6283.008539689d, 0.241332086d,$
         0.000228e-6,   -6284.056171060d, 2.657323816d,$
         0.000166e-6,    7238.675591600d, 5.930629110d,$
         0.000167e-6,    3097.883822726d, 5.570955333d,$
         0.000159e-6,    -323.505416657d, 5.786670700d,$
         0.000154e-6,   -4136.910433516d, 1.517805532d,$
         0.000176e-6,   12029.347187887d, 3.139266834d,$
         0.000167e-6,   12132.439962106d, 3.556352289d,$
         0.000153e-6,     202.253395174d, 1.463313961d,$
         0.000157e-6,   17267.268201691d, 1.586837396d,$
         0.000142e-6,   83996.847317911d, 0.022670115d,$
         0.000152e-6,   17260.154654690d, 0.708528947d,$
         0.000144e-6,    6084.003848555d, 5.187075177d,$
         0.000135e-6,    5756.566278634d, 1.993229262d,$
         0.000134e-6,    5750.203491159d, 3.457197134d,$
         0.000144e-6,    5326.786694021d, 6.066193291d,$
         0.000160e-6,   11015.106477335d, 1.710431974d,$
         0.000133e-6,    3634.621024518d, 2.836451652d,$
         0.000134e-6,   18073.704938650d, 5.453106665d,$
         0.000134e-6,    1162.474704408d, 5.326898811d,$
         0.000128e-6,    5642.198242609d, 2.511652591d,$
         0.000160e-6,     632.783739313d, 5.628785365d,$
         0.000132e-6,   13916.019109642d, 0.819294053d,$
         0.000122e-6,   14314.168113050d, 5.677408071d,$
         0.000125e-6,   12359.966151546d, 5.251984735d,$
         0.000121e-6,    5749.452731634d, 2.210924603d,$
         0.000136e-6,    -245.831646229d, 1.646502367d,$
         0.000120e-6,    5757.317038160d, 3.240883049d,$
         0.000134e-6,   12146.667056108d, 3.059480037d,$
         0.000137e-6,    6206.809778716d, 1.867105418d,$
         0.000141e-6,   17253.041107690d, 2.069217456d,$
         0.000129e-6,   -7477.522860216d, 2.781469314d,$
         0.000116e-6,    5540.085789459d, 4.281176991d,$
         0.000116e-6,    9779.108676125d, 3.320925381d,$
         0.000129e-6,    5237.921013804d, 3.497704076d,$
         0.000113e-6,    5959.570433334d, 0.983210840d,$
         0.000122e-6,    6282.095528923d, 2.674938860d,$
         0.000140e-6,     -11.045700264d, 4.957936982d,$
         0.000108e-6,   23543.230504682d, 1.390113589d,$
         0.000106e-6,  -12569.674818332d, 0.429631317d,$
         0.000110e-6,    -266.607041722d, 5.501340197d,$
         0.000115e-6,   12559.038152982d, 4.691456618d,$
         0.000134e-6,   -2388.894020449d, 0.577313584d,$
         0.000109e-6,   10440.274292604d, 6.218148717d,$
         0.000102e-6,    -543.918059096d, 1.477842615d,$
         0.000108e-6,   21228.392023546d, 2.237753948d,$
         0.000101e-6,   -4535.059436924d, 3.100492232d,$
         0.000103e-6,      76.266071276d, 5.594294322d,$
         0.000104e-6,     949.175608970d, 5.674287810d,$
         0.000101e-6,   13517.870106233d, 2.196632348d,$
         0.000100e-6,   11933.367960670d, 4.056084160d,$
         4.322990e-6,    6283.075849991d, 2.642893748d,$
         0.406495e-6,       0.000000000d, 4.712388980d,$
         0.122605e-6,   12566.151699983d, 2.438140634d,$
         0.019476e-6,     213.299095438d, 1.642186981d,$
         0.016916e-6,     529.690965095d, 4.510959344d,$
         0.013374e-6,      -3.523118349d, 1.502210314d,$
         0.008042e-6,      26.298319800d, 0.478549024d,$
         0.007824e-6,     155.420399434d, 5.254710405d,$
         0.004894e-6,    5746.271337896d, 4.683210850d,$
         0.004875e-6,    5760.498431898d, 0.759507698d,$
         0.004416e-6,    5223.693919802d, 6.028853166d,$
         0.004088e-6,      -7.113547001d, 0.060926389d,$
         0.004433e-6,   77713.771467920d, 3.627734103d,$
         0.003277e-6,   18849.227549974d, 2.327912542d,$
         0.002703e-6,    6062.663207553d, 1.271941729d,$
         0.003435e-6,    -775.522611324d, 0.747446224d,$
         0.002618e-6,    6076.890301554d, 3.633715689d,$
         0.003146e-6,     206.185548437d, 5.647874613d,$
         0.002544e-6,    1577.343542448d, 6.232904270d,$
         0.002218e-6,    -220.412642439d, 1.309509946d,$
         0.002197e-6,    5856.477659115d, 2.407212349d,$
         0.002897e-6,    5753.384884897d, 5.863842246d,$
         0.001766e-6,     426.598190876d, 0.754113147d,$
         0.001738e-6,    -796.298006816d, 2.714942671d,$
         0.001695e-6,     522.577418094d, 2.629369842d,$
         0.001584e-6,    5507.553238667d, 1.341138229d,$
         0.001503e-6,    -242.728603974d, 0.377699736d,$
         0.001552e-6,    -536.804512095d, 2.904684667d,$
         0.001370e-6,    -398.149003408d, 1.265599125d,$
         0.001889e-6,   -5573.142801634d, 4.413514859d,$
         0.001722e-6,    6069.776754553d, 2.445966339d,$
         0.001124e-6,    1059.381930189d, 5.041799657d,$
         0.001258e-6,     553.569402842d, 3.849557278d,$
         0.000831e-6,     951.718406251d, 2.471094709d,$
         0.000767e-6,    4694.002954708d, 5.363125422d,$
         0.000756e-6,    1349.867409659d, 1.046195744d,$
         0.000775e-6,     -11.045700264d, 0.245548001d,$
         0.000597e-6,    2146.165416475d, 4.543268798d,$
         0.000568e-6,    5216.580372801d, 4.178853144d,$
         0.000711e-6,    1748.016413067d, 5.934271972d,$
         0.000499e-6,   12036.460734888d, 0.624434410d,$
         0.000671e-6,   -1194.447010225d, 4.136047594d,$
         0.000488e-6,    5849.364112115d, 2.209679987d,$
         0.000621e-6,    6438.496249426d, 4.518860804d,$
         0.000495e-6,   -6286.598968340d, 1.868201275d,$
         0.000456e-6,    5230.807466803d, 1.271231591d,$
         0.000451e-6,    5088.628839767d, 0.084060889d,$
         0.000435e-6,    5643.178563677d, 3.324456609d,$
         0.000387e-6,   10977.078804699d, 4.052488477d,$
         0.000547e-6,  161000.685737473d, 2.841633844d,$
         0.000522e-6,    3154.687084896d, 2.171979966d,$
         0.000375e-6,    5486.777843175d, 4.983027306d,$
         0.000421e-6,    5863.591206116d, 4.546432249d,$
         0.000439e-6,    7084.896781115d, 0.522967921d,$
         0.000309e-6,    2544.314419883d, 3.172606705d,$
         0.000347e-6,    4690.479836359d, 1.479586566d,$
         0.000317e-6,     801.820931124d, 3.553088096d,$
         0.000262e-6,     419.484643875d, 0.606635550d,$
         0.000248e-6,    6836.645252834d, 3.014082064d,$
         0.000245e-6,   -1592.596013633d, 5.519526220d,$
         0.000225e-6,    4292.330832950d, 2.877956536d,$
         0.000214e-6,    7234.794256242d, 1.605227587d,$
         0.000205e-6,    5767.611978898d, 0.625804796d,$
         0.000180e-6,   10447.387839604d, 3.499954526d,$
         0.000229e-6,     199.072001436d, 5.632304604d,$
         0.000214e-6,     639.897286314d, 5.960227667d,$
         0.000175e-6,    -433.711737877d, 2.162417992d,$
         0.000209e-6,     515.463871093d, 2.322150893d,$
         0.000173e-6,    6040.347246017d, 2.556183691d,$
         0.000184e-6,    6309.374169791d, 4.732296790d,$
         0.000227e-6,  149854.400134205d, 5.385812217d,$
         0.000154e-6,    8031.092263058d, 5.120720920d,$
         0.000151e-6,    5739.157790895d, 4.815000443d,$
         0.000197e-6,    7632.943259650d, 0.222827271d,$
         0.000197e-6,      74.781598567d, 3.910456770d,$
         0.000138e-6,    6055.549660552d, 1.397484253d,$
         0.000149e-6,   -6127.655450557d, 5.333727496d,$
         0.000137e-6,    3894.181829542d, 4.281749907d,$
         0.000135e-6,    9437.762934887d, 5.979971885d,$
         0.000139e-6,   -2352.866153772d, 4.715630782d,$
         0.000142e-6,    6812.766815086d, 0.513330157d,$
         0.000120e-6,   -4705.732307544d, 0.194160689d,$
         0.000131e-6,  -71430.695617928d, 0.000379226d,$
         0.000124e-6,    6279.552731642d, 2.122264908d,$
         0.000108e-6,   -6256.777530192d, 0.883445696d,$
         0.143388e-6,    6283.075849991d, 1.131453581d,$
         0.006671e-6,   12566.151699983d, 0.775148887d,$
         0.001480e-6,     155.420399434d, 0.480016880d,$
         0.000934e-6,     213.299095438d, 6.144453084d,$
         0.000795e-6,     529.690965095d, 2.941595619d,$
         0.000673e-6,    5746.271337896d, 0.120415406d,$
         0.000672e-6,    5760.498431898d, 5.317009738d,$
         0.000389e-6,    -220.412642439d, 3.090323467d,$
         0.000373e-6,    6062.663207553d, 3.003551964d,$
         0.000360e-6,    6076.890301554d, 1.918913041d,$
         0.000316e-6,     -21.340641002d, 5.545798121d,$
         0.000315e-6,    -242.728603974d, 1.884932563d,$
         0.000278e-6,     206.185548437d, 1.266254859d,$
         0.000238e-6,    -536.804512095d, 4.532664830d,$
         0.000185e-6,     522.577418094d, 4.578313856d,$
         0.000245e-6,   18849.227549974d, 0.587467082d,$
         0.000180e-6,     426.598190876d, 5.151178553d,$
         0.000200e-6,     553.569402842d, 5.355983739d,$
         0.000141e-6,    5223.693919802d, 1.336556009d,$
         0.000104e-6,    5856.477659115d, 4.239842759d,$
         0.003826e-6,    6283.075849991d, 5.705257275d,$
         0.000303e-6,   12566.151699983d, 5.407132842d,$
         0.000209e-6,     155.420399434d, 1.989815753]
;  Time since J2000.0 in Julian millennia 
t = ( tdb - 51544.5 ) / 365250.0

;-------------------- Topocentric terms ------------------------------- 

;  Convert UT1 to local solar time in radians 
tsol = (ut1 mod 1.0) * !dpi *2.d - wl

;  Planetary arguments:  taken or derived from Bretagnon 1982
;  RLp = mean longituded, mean equinox of date
;  RGp = mean anomaly
;  RTp = mean longitude differenced, EMB minus planet 

;  EMB  
    rle = ( t * 6283.3196666635d + 1.75347031435d mod (!dpi*2.d) )
    rge = ( t * 6283.019551285d  + 6.24005997418d mod (!dpi*2.d) )

;  Jupiter  
    rtj = ( t * 5753.3848591241d + 1.15392381696d mod (!dpi*2.d) )

;  Saturn 
    rts = ( t * 6069.7767103654d + .87945355785d mod (!dpi*2.d) )

;  Lunar mean elongation:  derived from Meeus 1984  
    rdmoon = ( t * 77713.77144d + 5.198468d mod (!dpi*2.d) )

;  Topocentric terms (Moyer 1981 and Murray 1983) 
    wt = u * 2.9e-14     * sin ( tsol + rts ) $
      + u * 1e-13       * sin ( tsol - 2.0 * rge ) $
      + u * 1.33e-13    * sin ( tsol - rdmoon ) $
      + u * 1.33e-13    * sin ( tsol + rtj ) $
      - u * 2.29e-13    * sin ( tsol + 2.0 * rle + rge ) $
      - v * 2.2e-12     * sin ( rle + rge ) $
      + u * 5.312e-12   * sin ( tsol - rge ) $
      - u * 1.3677e-11  * sin ( tsol + 2.0 * rle ) $
      - v * 1.3184e-10  * cos ( rle ) $
      + u * 3.17679e-10 * sin ( tsol ) 

;  --------------- Fairhead model --------------------------------------- 

;   T**0 
    w0 = 0.0
    for i=474,1,-1 do begin
       i3 = i * 3
       w0 = w0 + fairhd[i3-3] * sin ( fairhd[i3-2] * t + fairhd[i3-1] )
    endfor

;  T**1 
    w1 = 0.0
    for i=679,475,-1 do begin
       i3 = i * 3
       w1 = w1 + fairhd[i3-3] * sin ( fairhd[i3-2] * t + fairhd[i3-1] )
    endfor

;  T**2 
    w2 = 0.0
    for i=764,680,-1 do begin
       i3 = i * 3
       w2 = w2 + fairhd[i3-3] * sin ( fairhd[i3-2] * t + fairhd[i3-1] )
    endfor

;  T**3 
    w3 = 0.0
    for i=784,765,-1 do begin
       i3 = i * 3
       w3 = w3 + fairhd[i3-3] * sin ( fairhd[i3-2] * t + fairhd[i3-1] )
    endfor

;  T**4  
    w4 = 0.0
    for i=787,785,-1 do begin
       i3 = i * 3
       w4 = w4 + fairhd[i3-3] * sin ( fairhd[i3-2] * t + fairhd[i3-1] )
    endfor

;  Multiply by powers of T and combine  
    wf = t * ( t * ( t * ( t * w4 + w3 ) + w2 ) + w1 ) + w0

;  Adjustments to use JPL planetary masses instead of IAU 
    wj = sin ( t * 6069.776754 + 4.021194 ) * 6.5e-10  $
       + sin ( t * 213.299095 + 5.543132 ) * 3.3e-10   $
       + sin ( t * 6208.294251 + 5.696701 ) * (-1.96e-9) $
       + sin ( t * 74.781599 + 2.4359 ) * (-1.73e-9)     $
       + 3.638e-8 * t * t

;  Final result:  TDB-TT in seconds  
    return, wt + wf + wj
end
